@@ -1,3 +1,4 @@
+import inspect
 from typing import List, Optional, Type
 
 from drf_spectacular.drainage import warn
@@ -125,14 +126,14 @@ class AutoSchema(BaseAutoSchema):
         """
         add a validation error response when unsafe methods have a request body
         or when a list view implements filtering with django-filters.
-        todo add a way to disable adding the 400 validation response on an
-         operation-basis. This is because "serializer.is_valid" has the option
-         of not raising an exception. At the very least, add docs to demo what
-         to override to accomplish that (maybe sth like
-         isinstance(self.view, SomeViewSet) and checking self.method)
         """
-        has_request_body = self.method in ("PUT", "PATCH", "POST") and bool(
-            self.get_request_serializer()
+        request_serializer = self.get_request_serializer()
+        has_request_body = self.method in ("PUT", "PATCH", "POST") and (
+            isinstance(request_serializer, serializers.Field)
+            or (
+                inspect.isclass(request_serializer)
+                and issubclass(request_serializer, serializers.Field)
+            )
         )
 
         filter_backends = get_django_filter_backends(self.get_filter_backends())
